# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Optional

from pydantic import Field as FieldInfo

from .._models import BaseModel
from .shared.references import References
from .shared.response_wrapper import ResponseWrapper

__all__ = [
    "StopsForRouteListResponse",
    "StopsForRouteListResponseData",
    "StopsForRouteListResponseDataEntry",
    "StopsForRouteListResponseDataEntryPolyline",
    "StopsForRouteListResponseDataEntryStopGrouping",
    "StopsForRouteListResponseDataEntryStopGroupingName",
    "StopsForRouteListResponseDataEntryStopGroupingPolyline",
]


class StopsForRouteListResponseDataEntryPolyline(BaseModel):
    length: Optional[int] = None

    levels: Optional[str] = None

    points: Optional[str] = None


class StopsForRouteListResponseDataEntryStopGroupingName(BaseModel):
    name: Optional[str] = None

    names: Optional[List[str]] = None

    type: Optional[str] = None


class StopsForRouteListResponseDataEntryStopGroupingPolyline(BaseModel):
    length: Optional[int] = None

    levels: Optional[str] = None

    points: Optional[str] = None


class StopsForRouteListResponseDataEntryStopGrouping(BaseModel):
    id: Optional[str] = None

    name: Optional[StopsForRouteListResponseDataEntryStopGroupingName] = None

    polylines: Optional[List[StopsForRouteListResponseDataEntryStopGroupingPolyline]] = None

    stop_ids: Optional[List[str]] = FieldInfo(alias="stopIds", default=None)


class StopsForRouteListResponseDataEntry(BaseModel):
    polylines: Optional[List[StopsForRouteListResponseDataEntryPolyline]] = None

    route_id: Optional[str] = FieldInfo(alias="routeId", default=None)

    stop_groupings: Optional[List[StopsForRouteListResponseDataEntryStopGrouping]] = FieldInfo(
        alias="stopGroupings", default=None
    )

    stop_ids: Optional[List[str]] = FieldInfo(alias="stopIds", default=None)


class StopsForRouteListResponseData(BaseModel):
    entry: StopsForRouteListResponseDataEntry

    references: References


class StopsForRouteListResponse(ResponseWrapper):
    data: StopsForRouteListResponseData



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Literal

import httpx

from ..types import report_problem_with_trip_retrieve_params
from .._types import Body, Omit, Query, Headers, NotGiven, omit, not_given
from .._utils import maybe_transform, async_maybe_transform
from .._compat import cached_property
from .._resource import SyncAPIResource, AsyncAPIResource
from .._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from .._base_client import make_request_options
from ..types.shared.response_wrapper import ResponseWrapper

__all__ = ["ReportProblemWithTripResource", "AsyncReportProblemWithTripResource"]


class ReportProblemWithTripResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> ReportProblemWithTripResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/OneBusAway/python-sdk#accessing-raw-response-data-eg-headers
        """
        return ReportProblemWithTripResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> ReportProblemWithTripResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/OneBusAway/python-sdk#with_streaming_response
        """
        return ReportProblemWithTripResourceWithStreamingResponse(self)

    def retrieve(
        self,
        trip_id: str,
        *,
        code: Literal[
            "vehicle_never_came",
            "vehicle_came_early",
            "vehicle_came_late",
            "wrong_headsign",
            "vehicle_does_not_stop_here",
            "other",
        ]
        | Omit = omit,
        service_date: int | Omit = omit,
        stop_id: str | Omit = omit,
        user_comment: str | Omit = omit,
        user_lat: float | Omit = omit,
        user_location_accuracy: float | Omit = omit,
        user_lon: float | Omit = omit,
        user_on_vehicle: bool | Omit = omit,
        user_vehicle_number: str | Omit = omit,
        vehicle_id: str | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> ResponseWrapper:
        """
        Submit a user-generated problem report for a particular trip.

        Args:
          code: A string code identifying the nature of the problem

          service_date: The service date of the trip

          stop_id: A stop ID indicating where the user is experiencing the problem

          user_comment: Additional comment text supplied by the user describing the problem

          user_lat: The reporting user’s current latitude

          user_location_accuracy: The reporting user’s location accuracy, in meters

          user_lon: The reporting user’s current longitude

          user_on_vehicle: Indicator if the user is on the transit vehicle experiencing the problem

          user_vehicle_number: The vehicle number, as reported by the user

          vehicle_id: The vehicle actively serving the trip

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not trip_id:
            raise ValueError(f"Expected a non-empty value for `trip_id` but received {trip_id!r}")
        return self._get(
            f"/api/where/report-problem-with-trip/{trip_id}.json",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=maybe_transform(
                    {
                        "code": code,
                        "service_date": service_date,
                        "stop_id": stop_id,
                        "user_comment": user_comment,
                        "user_lat": user_lat,
                        "user_location_accuracy": user_location_accuracy,
                        "user_lon": user_lon,
                        "user_on_vehicle": user_on_vehicle,
                        "user_vehicle_number": user_vehicle_number,
                        "vehicle_id": vehicle_id,
                    },
                    report_problem_with_trip_retrieve_params.ReportProblemWithTripRetrieveParams,
                ),
            ),
            cast_to=ResponseWrapper,
        )


class AsyncReportProblemWithTripResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncReportProblemWithTripResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/OneBusAway/python-sdk#accessing-raw-response-data-eg-headers
        """
        return AsyncReportProblemWithTripResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncReportProblemWithTripResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/OneBusAway/python-sdk#with_streaming_response
        """
        return AsyncReportProblemWithTripResourceWithStreamingResponse(self)

    async def retrieve(
        self,
        trip_id: str,
        *,
        code: Literal[
            "vehicle_never_came",
            "vehicle_came_early",
            "vehicle_came_late",
            "wrong_headsign",
            "vehicle_does_not_stop_here",
            "other",
        ]
        | Omit = omit,
        service_date: int | Omit = omit,
        stop_id: str | Omit = omit,
        user_comment: str | Omit = omit,
        user_lat: float | Omit = omit,
        user_location_accuracy: float | Omit = omit,
        user_lon: float | Omit = omit,
        user_on_vehicle: bool | Omit = omit,
        user_vehicle_number: str | Omit = omit,
        vehicle_id: str | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> ResponseWrapper:
        """
        Submit a user-generated problem report for a particular trip.

        Args:
          code: A string code identifying the nature of the problem

          service_date: The service date of the trip

          stop_id: A stop ID indicating where the user is experiencing the problem

          user_comment: Additional comment text supplied by the user describing the problem

          user_lat: The reporting user’s current latitude

          user_location_accuracy: The reporting user’s location accuracy, in meters

          user_lon: The reporting user’s current longitude

          user_on_vehicle: Indicator if the user is on the transit vehicle experiencing the problem

          user_vehicle_number: The vehicle number, as reported by the user

          vehicle_id: The vehicle actively serving the trip

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not trip_id:
            raise ValueError(f"Expected a non-empty value for `trip_id` but received {trip_id!r}")
        return await self._get(
            f"/api/where/report-problem-with-trip/{trip_id}.json",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=await async_maybe_transform(
                    {
                        "code": code,
                        "service_date": service_date,
                        "stop_id": stop_id,
                        "user_comment": user_comment,
                        "user_lat": user_lat,
                        "user_location_accuracy": user_location_accuracy,
                        "user_lon": user_lon,
                        "user_on_vehicle": user_on_vehicle,
                        "user_vehicle_number": user_vehicle_number,
                        "vehicle_id": vehicle_id,
                    },
                    report_problem_with_trip_retrieve_params.ReportProblemWithTripRetrieveParams,
                ),
            ),
            cast_to=ResponseWrapper,
        )


class ReportProblemWithTripResourceWithRawResponse:
    def __init__(self, report_problem_with_trip: ReportProblemWithTripResource) -> None:
        self._report_problem_with_trip = report_problem_with_trip

        self.retrieve = to_raw_response_wrapper(
            report_problem_with_trip.retrieve,
        )


class AsyncReportProblemWithTripResourceWithRawResponse:
    def __init__(self, report_problem_with_trip: AsyncReportProblemWithTripResource) -> None:
        self._report_problem_with_trip = report_problem_with_trip

        self.retrieve = async_to_raw_response_wrapper(
            report_problem_with_trip.retrieve,
        )


class ReportProblemWithTripResourceWithStreamingResponse:
    def __init__(self, report_problem_with_trip: ReportProblemWithTripResource) -> None:
        self._report_problem_with_trip = report_problem_with_trip

        self.retrieve = to_streamed_response_wrapper(
            report_problem_with_trip.retrieve,
        )


class AsyncReportProblemWithTripResourceWithStreamingResponse:
    def __init__(self, report_problem_with_trip: AsyncReportProblemWithTripResource) -> None:
        self._report_problem_with_trip = report_problem_with_trip

        self.retrieve = async_to_streamed_response_wrapper(
            report_problem_with_trip.retrieve,
        )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import httpx

from ..types import routes_for_location_list_params
from .._types import Body, Omit, Query, Headers, NotGiven, omit, not_given
from .._utils import maybe_transform, async_maybe_transform
from .._compat import cached_property
from .._resource import SyncAPIResource, AsyncAPIResource
from .._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from .._base_client import make_request_options
from ..types.routes_for_location_list_response import RoutesForLocationListResponse

__all__ = ["RoutesForLocationResource", "AsyncRoutesForLocationResource"]


class RoutesForLocationResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> RoutesForLocationResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/OneBusAway/python-sdk#accessing-raw-response-data-eg-headers
        """
        return RoutesForLocationResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> RoutesForLocationResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/OneBusAway/python-sdk#with_streaming_response
        """
        return RoutesForLocationResourceWithStreamingResponse(self)

    def list(
        self,
        *,
        lat: float,
        lon: float,
        lat_span: float | Omit = omit,
        lon_span: float | Omit = omit,
        query: str | Omit = omit,
        radius: float | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> RoutesForLocationListResponse:
        """
        routes-for-location

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return self._get(
            "/api/where/routes-for-location.json",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=maybe_transform(
                    {
                        "lat": lat,
                        "lon": lon,
                        "lat_span": lat_span,
                        "lon_span": lon_span,
                        "query": query,
                        "radius": radius,
                    },
                    routes_for_location_list_params.RoutesForLocationListParams,
                ),
            ),
            cast_to=RoutesForLocationListResponse,
        )


class AsyncRoutesForLocationResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncRoutesForLocationResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/OneBusAway/python-sdk#accessing-raw-response-data-eg-headers
        """
        return AsyncRoutesForLocationResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncRoutesForLocationResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/OneBusAway/python-sdk#with_streaming_response
        """
        return AsyncRoutesForLocationResourceWithStreamingResponse(self)

    async def list(
        self,
        *,
        lat: float,
        lon: float,
        lat_span: float | Omit = omit,
        lon_span: float | Omit = omit,
        query: str | Omit = omit,
        radius: float | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> RoutesForLocationListResponse:
        """
        routes-for-location

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return await self._get(
            "/api/where/routes-for-location.json",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=await async_maybe_transform(
                    {
                        "lat": lat,
                        "lon": lon,
                        "lat_span": lat_span,
                        "lon_span": lon_span,
                        "query": query,
                        "radius": radius,
                    },
                    routes_for_location_list_params.RoutesForLocationListParams,
                ),
            ),
            cast_to=RoutesForLocationListResponse,
        )


class RoutesForLocationResourceWithRawResponse:
    def __init__(self, routes_for_location: RoutesForLocationResource) -> None:
        self._routes_for_location = routes_for_location

        self.list = to_raw_response_wrapper(
            routes_for_location.list,
        )


class AsyncRoutesForLocationResourceWithRawResponse:
    def __init__(self, routes_for_location: AsyncRoutesForLocationResource) -> None:
        self._routes_for_location = routes_for_location

        self.list = async_to_raw_response_wrapper(
            routes_for_location.list,
        )


class RoutesForLocationResourceWithStreamingResponse:
    def __init__(self, routes_for_location: RoutesForLocationResource) -> None:
        self._routes_for_location = routes_for_location

        self.list = to_streamed_response_wrapper(
            routes_for_location.list,
        )


class AsyncRoutesForLocationResourceWithStreamingResponse:
    def __init__(self, routes_for_location: AsyncRoutesForLocationResource) -> None:
        self._routes_for_location = routes_for_location

        self.list = async_to_streamed_response_wrapper(
            routes_for_location.list,
        )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Optional

from pydantic import Field as FieldInfo

from .._models import BaseModel
from .shared.references import References
from .shared.response_wrapper import ResponseWrapper

__all__ = ["SearchForRouteListResponse", "SearchForRouteListResponseData", "SearchForRouteListResponseDataList"]


class SearchForRouteListResponseDataList(BaseModel):
    id: str

    agency_id: str = FieldInfo(alias="agencyId")

    type: int

    color: Optional[str] = None

    description: Optional[str] = None

    long_name: Optional[str] = FieldInfo(alias="longName", default=None)

    null_safe_short_name: Optional[str] = FieldInfo(alias="nullSafeShortName", default=None)

    short_name: Optional[str] = FieldInfo(alias="shortName", default=None)

    text_color: Optional[str] = FieldInfo(alias="textColor", default=None)

    url: Optional[str] = None


class SearchForRouteListResponseData(BaseModel):
    list: List[SearchForRouteListResponseDataList]

    out_of_range: bool = FieldInfo(alias="outOfRange")

    references: References

    limit_exceeded: Optional[bool] = FieldInfo(alias="limitExceeded", default=None)


class SearchForRouteListResponse(ResponseWrapper):
    data: Optional[SearchForRouteListResponseData] = None



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Optional

from pydantic import Field as FieldInfo

from .._models import BaseModel
from .shared.references import References
from .shared.response_wrapper import ResponseWrapper

__all__ = [
    "TripsForLocationListResponse",
    "TripsForLocationListResponseData",
    "TripsForLocationListResponseDataList",
    "TripsForLocationListResponseDataListSchedule",
    "TripsForLocationListResponseDataListScheduleStopTime",
    "TripsForLocationListResponseDataListStatus",
    "TripsForLocationListResponseDataListStatusLastKnownLocation",
    "TripsForLocationListResponseDataListStatusPosition",
]


class TripsForLocationListResponseDataListScheduleStopTime(BaseModel):
    arrival_time: Optional[int] = FieldInfo(alias="arrivalTime", default=None)

    departure_time: Optional[int] = FieldInfo(alias="departureTime", default=None)

    distance_along_trip: Optional[float] = FieldInfo(alias="distanceAlongTrip", default=None)

    historical_occupancy: Optional[str] = FieldInfo(alias="historicalOccupancy", default=None)

    stop_headsign: Optional[str] = FieldInfo(alias="stopHeadsign", default=None)

    stop_id: Optional[str] = FieldInfo(alias="stopId", default=None)


class TripsForLocationListResponseDataListSchedule(BaseModel):
    next_trip_id: str = FieldInfo(alias="nextTripId")

    previous_trip_id: str = FieldInfo(alias="previousTripId")

    stop_times: List[TripsForLocationListResponseDataListScheduleStopTime] = FieldInfo(alias="stopTimes")

    time_zone: str = FieldInfo(alias="timeZone")

    frequency: Optional[str] = None


class TripsForLocationListResponseDataListStatusLastKnownLocation(BaseModel):
    """Last known location of the transit vehicle."""

    lat: Optional[float] = None
    """Latitude of the last known location of the transit vehicle."""

    lon: Optional[float] = None
    """Longitude of the last known location of the transit vehicle."""


class TripsForLocationListResponseDataListStatusPosition(BaseModel):
    """Current position of the transit vehicle."""

    lat: Optional[float] = None
    """Latitude of the current position of the transit vehicle."""

    lon: Optional[float] = None
    """Longitude of the current position of the transit vehicle."""


class TripsForLocationListResponseDataListStatus(BaseModel):
    active_trip_id: str = FieldInfo(alias="activeTripId")
    """Trip ID of the trip the vehicle is actively serving."""

    block_trip_sequence: int = FieldInfo(alias="blockTripSequence")
    """Index of the active trip into the sequence of trips for the active block."""

    closest_stop: str = FieldInfo(alias="closestStop")
    """ID of the closest stop to the current location of the transit vehicle."""

    distance_along_trip: float = FieldInfo(alias="distanceAlongTrip")
    """Distance, in meters, the transit vehicle has progressed along the active trip."""

    last_known_distance_along_trip: float = FieldInfo(alias="lastKnownDistanceAlongTrip")
    """
    Last known distance along the trip received in real-time from the transit
    vehicle.
    """

    last_location_update_time: int = FieldInfo(alias="lastLocationUpdateTime")
    """Timestamp of the last known real-time location update from the transit vehicle."""

    last_update_time: int = FieldInfo(alias="lastUpdateTime")
    """Timestamp of the last known real-time update from the transit vehicle."""

    occupancy_capacity: int = FieldInfo(alias="occupancyCapacity")
    """Capacity of the transit vehicle in terms of occupancy."""

    occupancy_count: int = FieldInfo(alias="occupancyCount")
    """Current count of occupants in the transit vehicle."""

    occupancy_status: str = FieldInfo(alias="occupancyStatus")
    """Current occupancy status of the transit vehicle."""

    phase: str
    """Current journey phase of the trip."""

    predicted: bool
    """Indicates if real-time arrival info is available for this trip."""

    schedule_deviation: int = FieldInfo(alias="scheduleDeviation")
    """Deviation from the schedule in seconds (positive for late, negative for early)."""

    service_date: int = FieldInfo(alias="serviceDate")
    """
    Time, in milliseconds since the Unix epoch, of midnight for the start of the
    service date for the trip.
    """

    status: str
    """Current status modifiers for the trip."""

    total_distance_along_trip: float = FieldInfo(alias="totalDistanceAlongTrip")
    """Total length of the trip, in meters."""

    closest_stop_time_offset: Optional[int] = FieldInfo(alias="closestStopTimeOffset", default=None)
    """
    Time offset from the closest stop to the current position of the transit vehicle
    (in seconds).
    """

    frequency: Optional[str] = None
    """Information about frequency-based scheduling, if applicable to the trip."""

    last_known_location: Optional[TripsForLocationListResponseDataListStatusLastKnownLocation] = FieldInfo(
        alias="lastKnownLocation", default=None
    )
    """Last known location of the transit vehicle."""

    last_known_orientation: Optional[float] = FieldInfo(alias="lastKnownOrientation", default=None)
    """Last known orientation value received in real-time from the transit vehicle."""

    next_stop: Optional[str] = FieldInfo(alias="nextStop", default=None)
    """ID of the next stop the transit vehicle is scheduled to arrive at."""

    next_stop_time_offset: Optional[int] = FieldInfo(alias="nextStopTimeOffset", default=None)
    """
    Time offset from the next stop to the current position of the transit vehicle
    (in seconds).
    """

    orientation: Optional[float] = None
    """Orientation of the transit vehicle, represented as an angle in degrees."""

    position: Optional[TripsForLocationListResponseDataListStatusPosition] = None
    """Current position of the transit vehicle."""

    scheduled_distance_along_trip: Optional[float] = FieldInfo(alias="scheduledDistanceAlongTrip", default=None)
    """
    Distance, in meters, the transit vehicle is scheduled to have progressed along
    the active trip.
    """

    situation_ids: Optional[List[str]] = FieldInfo(alias="situationIds", default=None)
    """References to situation elements (if any) applicable to this trip."""

    vehicle_id: Optional[str] = FieldInfo(alias="vehicleId", default=None)
    """ID of the transit vehicle currently serving the trip."""


class TripsForLocationListResponseDataList(BaseModel):
    schedule: TripsForLocationListResponseDataListSchedule

    status: TripsForLocationListResponseDataListStatus

    trip_id: str = FieldInfo(alias="tripId")

    frequency: Optional[str] = None

    service_date: Optional[int] = FieldInfo(alias="serviceDate", default=None)

    situation_ids: Optional[List[str]] = FieldInfo(alias="situationIds", default=None)


class TripsForLocationListResponseData(BaseModel):
    list: List[TripsForLocationListResponseDataList]

    references: References

    limit_exceeded: Optional[bool] = FieldInfo(alias="limitExceeded", default=None)
    """Indicates if the limit of trips has been exceeded"""

    out_of_range: Optional[bool] = FieldInfo(alias="outOfRange", default=None)
    """Indicates if the search location is out of range"""


class TripsForLocationListResponse(ResponseWrapper):
    data: TripsForLocationListResponseData



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import datetime
from typing import Union
from typing_extensions import Annotated, TypedDict

from .._utils import PropertyInfo

__all__ = ["ScheduleForStopRetrieveParams"]


class ScheduleForStopRetrieveParams(TypedDict, total=False):
    date: Annotated[Union[str, datetime.date], PropertyInfo(format="iso8601")]
    """
    The date for which you want to request a schedule in the format YYYY-MM-DD
    (optional, defaults to the current date)
    """



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import httpx

from ..types import trip_detail_retrieve_params
from .._types import Body, Omit, Query, Headers, NotGiven, omit, not_given
from .._utils import maybe_transform, async_maybe_transform
from .._compat import cached_property
from .._resource import SyncAPIResource, AsyncAPIResource
from .._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from .._base_client import make_request_options
from ..types.trip_detail_retrieve_response import TripDetailRetrieveResponse

__all__ = ["TripDetailsResource", "AsyncTripDetailsResource"]


class TripDetailsResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> TripDetailsResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/OneBusAway/python-sdk#accessing-raw-response-data-eg-headers
        """
        return TripDetailsResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> TripDetailsResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/OneBusAway/python-sdk#with_streaming_response
        """
        return TripDetailsResourceWithStreamingResponse(self)

    def retrieve(
        self,
        trip_id: str,
        *,
        include_schedule: bool | Omit = omit,
        include_status: bool | Omit = omit,
        include_trip: bool | Omit = omit,
        service_date: int | Omit = omit,
        time: int | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> TripDetailRetrieveResponse:
        """
        Retrieve Trip Details

        Args:
          include_schedule: Whether to include the full schedule element in the tripDetails section
              (defaults to true).

          include_status: Whether to include the full status element in the tripDetails section (defaults
              to true).

          include_trip: Whether to include the full trip element in the references section (defaults to
              true).

          service_date: Service date for the trip as Unix time in milliseconds (optional).

          time: Time parameter to query the system at a specific time (optional).

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not trip_id:
            raise ValueError(f"Expected a non-empty value for `trip_id` but received {trip_id!r}")
        return self._get(
            f"/api/where/trip-details/{trip_id}.json",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=maybe_transform(
                    {
                        "include_schedule": include_schedule,
                        "include_status": include_status,
                        "include_trip": include_trip,
                        "service_date": service_date,
                        "time": time,
                    },
                    trip_detail_retrieve_params.TripDetailRetrieveParams,
                ),
            ),
            cast_to=TripDetailRetrieveResponse,
        )


class AsyncTripDetailsResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncTripDetailsResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/OneBusAway/python-sdk#accessing-raw-response-data-eg-headers
        """
        return AsyncTripDetailsResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncTripDetailsResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/OneBusAway/python-sdk#with_streaming_response
        """
        return AsyncTripDetailsResourceWithStreamingResponse(self)

    async def retrieve(
        self,
        trip_id: str,
        *,
        include_schedule: bool | Omit = omit,
        include_status: bool | Omit = omit,
        include_trip: bool | Omit = omit,
        service_date: int | Omit = omit,
        time: int | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> TripDetailRetrieveResponse:
        """
        Retrieve Trip Details

        Args:
          include_schedule: Whether to include the full schedule element in the tripDetails section
              (defaults to true).

          include_status: Whether to include the full status element in the tripDetails section (defaults
              to true).

          include_trip: Whether to include the full trip element in the references section (defaults to
              true).

          service_date: Service date for the trip as Unix time in milliseconds (optional).

          time: Time parameter to query the system at a specific time (optional).

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not trip_id:
            raise ValueError(f"Expected a non-empty value for `trip_id` but received {trip_id!r}")
        return await self._get(
            f"/api/where/trip-details/{trip_id}.json",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=await async_maybe_transform(
                    {
                        "include_schedule": include_schedule,
                        "include_status": include_status,
                        "include_trip": include_trip,
                        "service_date": service_date,
                        "time": time,
                    },
                    trip_detail_retrieve_params.TripDetailRetrieveParams,
                ),
            ),
            cast_to=TripDetailRetrieveResponse,
        )


class TripDetailsResourceWithRawResponse:
    def __init__(self, trip_details: TripDetailsResource) -> None:
        self._trip_details = trip_details

        self.retrieve = to_raw_response_wrapper(
            trip_details.retrieve,
        )


class AsyncTripDetailsResourceWithRawResponse:
    def __init__(self, trip_details: AsyncTripDetailsResource) -> None:
        self._trip_details = trip_details

        self.retrieve = async_to_raw_response_wrapper(
            trip_details.retrieve,
        )


class TripDetailsResourceWithStreamingResponse:
    def __init__(self, trip_details: TripDetailsResource) -> None:
        self._trip_details = trip_details

        self.retrieve = to_streamed_response_wrapper(
            trip_details.retrieve,
        )


class AsyncTripDetailsResourceWithStreamingResponse:
    def __init__(self, trip_details: AsyncTripDetailsResource) -> None:
        self._trip_details = trip_details

        self.retrieve = async_to_streamed_response_wrapper(
            trip_details.retrieve,
        )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Optional

from pydantic import Field as FieldInfo

from .._models import BaseModel
from .shared.references import References
from .shared.response_wrapper import ResponseWrapper

__all__ = ["RouteIDsForAgencyListResponse", "RouteIDsForAgencyListResponseData"]


class RouteIDsForAgencyListResponseData(BaseModel):
    list: List[str]

    references: References

    limit_exceeded: Optional[bool] = FieldInfo(alias="limitExceeded", default=None)


class RouteIDsForAgencyListResponse(ResponseWrapper):
    data: RouteIDsForAgencyListResponseData



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Optional

from pydantic import Field as FieldInfo

from .._models import BaseModel
from .shared.references import References
from .shared.response_wrapper import ResponseWrapper

__all__ = [
    "AgenciesWithCoverageListResponse",
    "AgenciesWithCoverageListResponseData",
    "AgenciesWithCoverageListResponseDataList",
]


class AgenciesWithCoverageListResponseDataList(BaseModel):
    agency_id: str = FieldInfo(alias="agencyId")

    lat: float

    lat_span: float = FieldInfo(alias="latSpan")

    lon: float

    lon_span: float = FieldInfo(alias="lonSpan")


class AgenciesWithCoverageListResponseData(BaseModel):
    list: List[AgenciesWithCoverageListResponseDataList]

    references: References

    limit_exceeded: Optional[bool] = FieldInfo(alias="limitExceeded", default=None)


class AgenciesWithCoverageListResponse(ResponseWrapper):
    data: AgenciesWithCoverageListResponseData
